==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QDragLeaveEvent_shell.cpp <==
#include "QDragLeaveEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QDragLeaveEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDragLeaveEvent")
    QDragLeaveEvent *_ptr = reinterpret_cast<QDragLeaveEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QDragLeaveEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QDragLeaveEvent_shell) ); }

jmethodID QDragLeaveEvent_shell::__shell_javaMethod(int pos) const { return QDragLeaveEvent_shell::__shell()->javaMethod(typeid(QDragLeaveEvent), pos); }

// emitting (writeShellConstructor)
QDragLeaveEvent_shell::QDragLeaveEvent_shell()
    : QDragLeaveEvent()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QDragLeaveEvent::QDragLeaveEvent_shell()", QDragLeaveEvent_shell::__shell())
    QDragLeaveEvent_shell::__shell()->constructed(typeid(QDragLeaveEvent));
}

QDragLeaveEvent_shell::QDragLeaveEvent_shell(const QDragLeaveEvent& arg__1)
    : QDragLeaveEvent(arg__1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QDragLeaveEvent::QDragLeaveEvent_shell(const QDragLeaveEvent& arg__1)", QDragLeaveEvent_shell::__shell())
    QDragLeaveEvent_shell::__shell()->constructed(typeid(QDragLeaveEvent));
}

// emitting (writeShellDestructor)
QDragLeaveEvent_shell::~QDragLeaveEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QDragLeaveEvent::~QDragLeaveEvent()", QDragLeaveEvent_shell::__shell())
    QDragLeaveEvent_shell::__shell()->destructed(typeid(QDragLeaveEvent));
}

void QDragLeaveEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QDragLeaveEvent_shell*>(ptr)->QDragLeaveEvent_shell::__shell()->tryDeleteShell(typeid(QDragLeaveEvent));
}

// emitting Virtual overrides (virtualFunctions)
QDragLeaveEvent* QDragLeaveEvent_shell::clone() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QDragLeaveEvent::clone()const", QDragLeaveEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QDragLeaveEvent*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QDragLeaveEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QDragLeaveEvent* >(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnership(__jni_env, __java_return_value);
                } else {
                    QDragLeaveEvent_shell::__shell()->warnForMethod("QDragLeaveEvent::clone()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QDragLeaveEvent::clone()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QDragLeaveEvent::clone();
        }
    }else{
        return QDragLeaveEvent::clone();
    }
}

void QDragLeaveEvent_shell::setAccepted(bool accepted0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QDragLeaveEvent::", QDragLeaveEvent_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QDragLeaveEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, accepted0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QDragLeaveEvent_shell::__shell()->warnForMethod("QDragLeaveEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QDragLeaveEvent::");
            } QTJAMBI_TRY_END
        }else{
            QEvent::setAccepted(static_cast<bool>(accepted0));
        }
    }else{
        QEvent::setAccepted(static_cast<bool>(accepted0));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
void QDragLeaveEvent_access::__qt_assign_cref_QDragLeaveEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0)
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    const QDragLeaveEvent& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QDragLeaveEvent>(__jni_env, other0);
    QDragLeaveEvent::operator=(__qt_other0);
}

// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QDragLeaveEvent_access::__qt_clone(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QDragLeaveEvent* __qt_return_value = QDragLeaveEvent::clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    } else {
        QDragLeaveEvent* __qt_return_value = clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new QDragLeaveEvent()
void __qt_construct_QDragLeaveEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDragLeaveEvent()")
    Q_UNUSED(__java_arguments)
    QDragLeaveEvent *__qt_this = new(__qtjambi_ptr) QDragLeaveEvent_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QDragLeaveEvent(QDragLeaveEvent)
void __qt_construct_QDragLeaveEvent_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDragLeaveEvent(QDragLeaveEvent)")
    jobject arg__1 = __java_arguments[0].l;
    const QDragLeaveEvent& __qt_arg__1 = qtjambi_cast<const QDragLeaveEvent& >(__jni_env, arg__1);
    QDragLeaveEvent *__qt_this = new(__qtjambi_ptr) QDragLeaveEvent_shell(__qt_arg__1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QDragLeaveEvent_shell
void __qt_destruct_QDragLeaveEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDragLeaveEvent")
    reinterpret_cast<QDragLeaveEvent_shell*>(ptr)->~QDragLeaveEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDragLeaveEvent::QDragLeaveEvent()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QDragLeaveEvent_initialize_1native__Lio_qt_gui_QDragLeaveEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDragLeaveEvent::QDragLeaveEvent()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDragLeaveEvent_0, sizeof(QDragLeaveEvent_shell), typeid(QDragLeaveEvent), true, &deleter_QDragLeaveEvent, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDragLeaveEvent::QDragLeaveEvent(QDragLeaveEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QDragLeaveEvent_initialize_1native__Lio_qt_gui_QDragLeaveEvent_2Lio_qt_gui_QDragLeaveEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDragLeaveEvent::QDragLeaveEvent(QDragLeaveEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDragLeaveEvent_1, sizeof(QDragLeaveEvent_shell), typeid(QDragLeaveEvent), true, &deleter_QDragLeaveEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDragLeaveEvent::operator=(QDragLeaveEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QDragLeaveEvent_assign_1native_1cref_1QDragLeaveEvent__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDragLeaveEvent *__qt_this = QtJambiAPI::objectFromNativeId<QDragLeaveEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDragLeaveEvent::operator=(QDragLeaveEvent)", __qt_this)
        static_cast<QDragLeaveEvent_access*>(__qt_this)->__qt_assign_cref_QDragLeaveEvent(__jni_env, __this_nativeId, other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDragLeaveEvent::clone()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QDragLeaveEvent_clone_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDragLeaveEvent *__qt_this = QtJambiAPI::objectFromNativeId<QDragLeaveEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDragLeaveEvent::clone()const", __qt_this)
        __java_return_value = static_cast<const QDragLeaveEvent_access*>(__qt_this)->__qt_clone(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QDragLeaveEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QDragLeaveEvent>("QDragLeaveEvent", "io/qt/gui/QDragLeaveEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "clone", "()Lio/qt/gui/QDragLeaveEvent;"),
        FunctionInfo(/* 1 */ "setAccepted", "(Z)V")});
    registerConstructorInfos(typeId, &__qt_destruct_QDragLeaveEvent, {
        ConstructorInfo(&__qt_construct_QDragLeaveEvent_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QDragLeaveEvent_1, "Lio/qt/gui/QDragLeaveEvent;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDragLeaveEvent);
    registerSizeOfShell(typeId, sizeof(QDragLeaveEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QDragLeaveEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QDragLeaveEvent_shell.cpp <==
#include "QDragLeaveEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QDragLeaveEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDragLeaveEvent")
    QDragLeaveEvent *_ptr = reinterpret_cast<QDragLeaveEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QDragLeaveEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QDragLeaveEvent_shell) ); }

jmethodID QDragLeaveEvent_shell::__shell_javaMethod(int pos) const { return QDragLeaveEvent_shell::__shell()->javaMethod(typeid(QDragLeaveEvent), pos); }

// emitting (writeShellConstructor)
QDragLeaveEvent_shell::QDragLeaveEvent_shell()
    : QDragLeaveEvent()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QDragLeaveEvent::QDragLeaveEvent_shell()", QDragLeaveEvent_shell::__shell())
    QDragLeaveEvent_shell::__shell()->constructed(typeid(QDragLeaveEvent));
}

QDragLeaveEvent_shell::QDragLeaveEvent_shell(const QDragLeaveEvent& arg__1)
    : QDragLeaveEvent(arg__1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QDragLeaveEvent::QDragLeaveEvent_shell(const QDragLeaveEvent& arg__1)", QDragLeaveEvent_shell::__shell())
    QDragLeaveEvent_shell::__shell()->constructed(typeid(QDragLeaveEvent));
}

// emitting (writeShellDestructor)
QDragLeaveEvent_shell::~QDragLeaveEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QDragLeaveEvent::~QDragLeaveEvent()", QDragLeaveEvent_shell::__shell())
    QDragLeaveEvent_shell::__shell()->destructed(typeid(QDragLeaveEvent));
}

void QDragLeaveEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QDragLeaveEvent_shell*>(ptr)->QDragLeaveEvent_shell::__shell()->tryDeleteShell(typeid(QDragLeaveEvent));
}

// emitting Virtual overrides (virtualFunctions)
QDragLeaveEvent* QDragLeaveEvent_shell::clone() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QDragLeaveEvent::clone()const", QDragLeaveEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QDragLeaveEvent*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QDragLeaveEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QDragLeaveEvent* >(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnership(__jni_env, __java_return_value);
                } else {
                    QDragLeaveEvent_shell::__shell()->warnForMethod("QDragLeaveEvent::clone()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QDragLeaveEvent::clone()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QDragLeaveEvent::clone();
        }
    }else{
        return QDragLeaveEvent::clone();
    }
}

void QDragLeaveEvent_shell::setAccepted(bool accepted0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QDragLeaveEvent::", QDragLeaveEvent_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QDragLeaveEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, accepted0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QDragLeaveEvent_shell::__shell()->warnForMethod("QDragLeaveEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QDragLeaveEvent::");
            } QTJAMBI_TRY_END
        }else{
            QEvent::setAccepted(static_cast<bool>(accepted0));
        }
    }else{
        QEvent::setAccepted(static_cast<bool>(accepted0));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
void QDragLeaveEvent_access::__qt_assign_cref_QDragLeaveEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0)
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    const QDragLeaveEvent& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QDragLeaveEvent>(__jni_env, other0);
    QDragLeaveEvent::operator=(__qt_other0);
}

// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QDragLeaveEvent_access::__qt_clone_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QDragLeaveEvent* __qt_return_value = QDragLeaveEvent::clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    } else {
        QDragLeaveEvent* __qt_return_value = clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new QDragLeaveEvent()
void __qt_construct_QDragLeaveEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDragLeaveEvent()")
    Q_UNUSED(__java_arguments)
    QDragLeaveEvent *__qt_this = new(__qtjambi_ptr) QDragLeaveEvent_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QDragLeaveEvent::QDragLeaveEvent()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QDragLeaveEvent_initialize_1native__Lio_qt_gui_QDragLeaveEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDragLeaveEvent::QDragLeaveEvent()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDragLeaveEvent, sizeof(QDragLeaveEvent_shell), typeid(QDragLeaveEvent), true, &deleter_QDragLeaveEvent, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QDragLeaveEvent(QDragLeaveEvent)
void __qt_construct_QDragLeaveEvent_cref_QDragLeaveEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDragLeaveEvent(QDragLeaveEvent)")
    jobject arg__1 = __java_arguments[0].l;
    const QDragLeaveEvent& __qt_arg__1 = qtjambi_cast<const QDragLeaveEvent& >(__jni_env, arg__1);
    QDragLeaveEvent *__qt_this = new(__qtjambi_ptr) QDragLeaveEvent_shell(__qt_arg__1);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QDragLeaveEvent::QDragLeaveEvent(QDragLeaveEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QDragLeaveEvent_initialize_1native__Lio_qt_gui_QDragLeaveEvent_2Lio_qt_gui_QDragLeaveEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDragLeaveEvent::QDragLeaveEvent(QDragLeaveEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDragLeaveEvent_cref_QDragLeaveEvent, sizeof(QDragLeaveEvent_shell), typeid(QDragLeaveEvent), true, &deleter_QDragLeaveEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDragLeaveEvent_shell
void __qt_destruct_QDragLeaveEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDragLeaveEvent")
    reinterpret_cast<QDragLeaveEvent_shell*>(ptr)->~QDragLeaveEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDragLeaveEvent::operator=(QDragLeaveEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QDragLeaveEvent_assign_1native_1cref_1QDragLeaveEvent__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDragLeaveEvent *__qt_this = QtJambiAPI::objectFromNativeId<QDragLeaveEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDragLeaveEvent::operator=(QDragLeaveEvent)", __qt_this)
        static_cast<QDragLeaveEvent_access*>(__qt_this)->__qt_assign_cref_QDragLeaveEvent(__jni_env, __this_nativeId, other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDragLeaveEvent::clone()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QDragLeaveEvent_clone_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDragLeaveEvent *__qt_this = QtJambiAPI::objectFromNativeId<QDragLeaveEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDragLeaveEvent::clone()const", __qt_this)
        __java_return_value = static_cast<const QDragLeaveEvent_access*>(__qt_this)->__qt_clone_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QDragLeaveEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QDragLeaveEvent>("QDragLeaveEvent", "io/qt/gui/QDragLeaveEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "clone", "()Lio/qt/gui/QDragLeaveEvent;"),
        FunctionInfo(/* 1 */ "setAccepted", "(Z)V")});
    registerConstructorInfos(typeId, &__qt_destruct_QDragLeaveEvent, {
        ConstructorInfo(&__qt_construct_QDragLeaveEvent, nullptr)
       ,ConstructorInfo(&__qt_construct_QDragLeaveEvent_cref_QDragLeaveEvent, "Lio/qt/gui/QDragLeaveEvent;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDragLeaveEvent);
    registerSizeOfShell(typeId, sizeof(QDragLeaveEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QDragLeaveEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
